#
# spec file for package mujs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mujs
Version:        1.3.5
Release:        1.3
Summary:        An embeddable Javascript interpreter
License:        AGPL-3.0-or-later
Group:          Development/Languages/C and C++
URL:            https://mujs.com
Source0:        https://mujs.com/downloads/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(readline)
%else
BuildRequires:  readline-devel
%endif

%description
MuJS is a lightweight Javascript interpreter designed for embedding in other software to extend them with scripting capabilities.

%package devel
Summary:        MuJS development files
Group:          Development/Languages/C and C++
Provides:       %{name}-static = %{version}

%description devel
This package provides the MuJS static library.

%prep
%autosetup -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%make_build debug CFLAGS="%{optflags} -fPIC"

%install
%make_install prefix="%{_prefix}" libdir="%{_libdir}" CFLAGS="%{optflags} -fPIC"

%files
%license COPYING
%doc AUTHORS README
%{_bindir}/%{name}
%{_bindir}/%{name}-pp

%files devel
%license COPYING
%doc AUTHORS README
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.a

%changelog
* Fri Dec 13 2024 Илья Индиго <ilya@ilya.top>
- Updated to 1.3.5
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.3.5
  * Fixed bug with String.prototype.split(RegExp).
* Thu Feb  1 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Updated to 1.3.4
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.3.4
  * Finalize user data if object allocation fails.
  * Fix bug when cleaning up after allocation error.
  * Handle sign when converting integer strings to numbers.
  * Allow disabling readline support in Makefile.
* Fri May 19 2023 Илья Индиго <ilya@ilya.top>
- Updated to 1.3.3
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.3.3
* Sat Mar 11 2023 Luigi Baldoni <aloisio@gmx.com>
- Allow build on leap
* Sat Jan 14 2023 ecsos <ecsos@opensuse.org>
- Update to 1.3.2
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.3.2
  * 1.3.2 patch release for UAF bug fix.
  * Bug 706057: Fix use-after-free in getOwnPropertyDescriptor.
  * Set length of output array Array.prototype.map.
- Update to 1.3.1
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.3.1
  * Make a patch release for important iterator bug fix.
  * Issue #166: Use special iterator for string and array indices.
  * Enable choice of library version for shell
  * Use $(@D) instead of $(dir $@)
- Update to 1.3.0
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.3.0
  * Avoid freeing buffer twice in case of error.
  * Fast path for "simple" arrays.
  * Bug 705775: Fix double fclose in pretty-printing tool.
  * Makefile: fix parallel builds
  * Guard state initialization with try to avoid panic in initialization.
  * Add js_isbooleanobject and js_isdateobject functions.
  * Issue #161: Cope with empty programs in mujs-pp.
  * Issue #161: Don't fclose a FILE that is NULL.
  * Issue #162: Check stack overflow during regexp compilation.
  * Bug 705052: Don't use private STACK/TOP macros in jsstate.c
  * Add "console" object to mujs shell.
  * Issue #156: Fix check for duplicate formal parameters when strict.
  * Some minor optimizations to Ap_join.
  * array join: avoid strcat, speedup from O(N^2) to O(N)
- Drop mujs-1.2.0-stack-exhaustion.patch because now in upstream.
* Wed May 18 2022 Илья Индиго <ilya@ilya.top>
- Added mujs-1.2.0-stack-exhaustion.patch (CVE-2022-30974, boo#1199678).
* Tue Feb 15 2022 Илья Индиго <ilya@ilya.top>
- Updated to 1.2.0
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.2.0
  * Fixed heap buffer overflow (CVE-2021-45005, boo#1195954).
* Sun Jun 27 2021 Илья Индиго <ilya@ilya.top>
- Updated to 1.1.3
  * https://git.ghostscript.com/?p=mujs.git;a=log;h=refs/tags/1.1.3
  * Fixed error in Array.prototype.toString().
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update mujs 1.1.2
  * Check for overflow when reading floating point exponent
  * Fix use-after-free in regexp source property access.
* Wed Apr 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update mujs 1.1.1
  * Fix: Always create new scope for eval()
  * Don't redefine/reset existing vars in script code
  * Fix: RegExp.prototype should be a regular expression object
  * Throw when redefining non-configurable/readonly properties
  * Array:  Fix crash when length is negative
  * fix split doesn't convert context to string if no argument is passed
  * Parse integers with floats to support large numbers.
  * Optimize array construction bytecode.
  * Fix: Expose type of value as an enum with js_type()
  * Fixed js_strtol: Prevent negative table indexing in
- Update mujs 1.1.0
  * Don't allow creating new properties on transient objects.
  * Fixed escape characters in regex parser
  * Handle NaN in Date accessors
  * Handle undefined argument to Error constructor
- Fixed RPM error because of missing RPM group
* Thu Mar 11 2021 Илья Индиго <ilya@ilya.top>
- Initialization mujs 1.0.9.
